==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/74/74d2bd1e545e10f8a770f9efd3afe55a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PageBundle/Translations/en_US/flashes.ini */
class __TwigTemplate_b6afcf0a37bbe0d82b5714845a29d5ac extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.page.error.notfound=\"No page with an id of %id% was found!\"
mautic.page.notice.activated=\"<a href='%url%' data-toggle='ajax' data-menu-link='mautic_page_index'><strong>%name%</strong></a> is now active as the main page!\"
mautic.page.notice.batch_deleted=\"%count% pages have been deleted!\"
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PageBundle/Translations/en_US/flashes.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PageBundle/Translations/en_US/flashes.ini", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Translations/en_US/flashes.ini");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/74/74d2bd1e545e10f8a770f9efd3afe55a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PageBundle/Translations/en_US/flashes.ini */
class __TwigTemplate_b6afcf0a37bbe0d82b5714845a29d5ac extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.page.error.notfound=\"No page with an id of %id% was found!\"
mautic.page.notice.activated=\"<a href='%url%' data-toggle='ajax' data-menu-link='mautic_page_index'><strong>%name%</strong></a> is now active as the main page!\"
mautic.page.notice.batch_deleted=\"%count% pages have been deleted!\"
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PageBundle/Translations/en_US/flashes.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PageBundle/Translations/en_US/flashes.ini", "/var/www/html/production-demo/app/bundles/PageBundle/Translations/en_US/flashes.ini");
    }
}
